@@ -36,6 +36,6 @@ pub use {
 };
 
 pub use chrono::Duration;
-pub use url::Url;
+pub use url::{ParseError as UrlParseError, Url};
 
 pub type CredentialsToken = CsString<64>;
