@@ -115,6 +115,21 @@ impl<V, const N: usize> BaseString<V, N> {
     }
 }
 
+impl<V, const N: usize> TryFrom<String> for BaseString<V, N>
+where
+    V: StringVariant,
+{
+    type Error = StringError;
+
+    fn try_from(s: String) -> Result<Self, Self::Error> {
+        V::validate(&s)?;
+        Ok(BaseString {
+            s,
+            _marker: PhantomData::default(),
+        })
+    }
+}
+
 impl<V, const N: usize> From<BaseString<V, N>> for String {
     fn from(s: BaseString<V, N>) -> String {
         s.s
